@@ -50,7 +50,7 @@ class Exceptions:
 
 class IoTDataPlaneClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -59,16 +59,16 @@ class IoTDataPlaneClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def delete_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> DeleteThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
-        [Show boto3-stubs documentation](./client.md#delete-thing-shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3-stubs documentation](./client.md#delete_thing_shadow)
         """
 
     def generate_presigned_url(
@@ -79,29 +79,29 @@ class IoTDataPlaneClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_thing_shadow(
         self, thingName: str, shadowName: str = None
     ) -> GetThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
-        [Show boto3-stubs documentation](./client.md#get-thing-shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3-stubs documentation](./client.md#get_thing_shadow)
         """
 
     def list_named_shadows_for_thing(
         self, thingName: str, nextToken: str = None, pageSize: int = None
     ) -> ListNamedShadowsForThingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
-        [Show boto3-stubs documentation](./client.md#list-named-shadows-for-thing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3-stubs documentation](./client.md#list_named_shadows_for_thing)
         """
 
     def publish(self, topic: str, qos: int = None, payload: Union[bytes, IO[bytes]] = None) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         [Show boto3-stubs documentation](./client.md#publish)
         """
 
@@ -109,6 +109,6 @@ class IoTDataPlaneClient:
         self, thingName: str, payload: Union[bytes, IO[bytes]], shadowName: str = None
     ) -> UpdateThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
-        [Show boto3-stubs documentation](./client.md#update-thing-shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3-stubs documentation](./client.md#update_thing_shadow)
         """
