@@ -1,7 +1,7 @@
 """
 Type annotations for iot-data service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/type_defs.html)
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -27,20 +27,35 @@ __all__ = (
     "UpdateThingShadowResponseTypeDef",
 )
 
+DeleteThingShadowResponseTypeDef = TypedDict(
+    "DeleteThingShadowResponseTypeDef",
+    {
+        "payload": Union[bytes, IO[bytes]],
+    },
+)
 
-class DeleteThingShadowResponseTypeDef(TypedDict):
-    payload: Union[bytes, IO[bytes]]
+GetThingShadowResponseTypeDef = TypedDict(
+    "GetThingShadowResponseTypeDef",
+    {
+        "payload": Union[bytes, IO[bytes]],
+    },
+    total=False,
+)
 
+ListNamedShadowsForThingResponseTypeDef = TypedDict(
+    "ListNamedShadowsForThingResponseTypeDef",
+    {
+        "results": List[str],
+        "nextToken": str,
+        "timestamp": int,
+    },
+    total=False,
+)
 
-class GetThingShadowResponseTypeDef(TypedDict, total=False):
-    payload: Union[bytes, IO[bytes]]
-
-
-class ListNamedShadowsForThingResponseTypeDef(TypedDict, total=False):
-    results: List[str]
-    nextToken: str
-    timestamp: int
-
-
-class UpdateThingShadowResponseTypeDef(TypedDict, total=False):
-    payload: Union[bytes, IO[bytes]]
+UpdateThingShadowResponseTypeDef = TypedDict(
+    "UpdateThingShadowResponseTypeDef",
+    {
+        "payload": Union[bytes, IO[bytes]],
+    },
+    total=False,
+)
